@@ -45,59 +45,59 @@ use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::MediaUtils;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
-use Google::Ads::GoogleAds::V22::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V22::Resources::Campaign;
-use Google::Ads::GoogleAds::V22::Resources::ShoppingSetting;
-use Google::Ads::GoogleAds::V22::Resources::CampaignCriterion;
-use Google::Ads::GoogleAds::V22::Resources::CampaignAsset;
-use Google::Ads::GoogleAds::V22::Resources::Asset;
-use Google::Ads::GoogleAds::V22::Resources::AssetAutomationSetting;
-use Google::Ads::GoogleAds::V22::Resources::AssetGroup;
-use Google::Ads::GoogleAds::V22::Resources::AssetGroupAsset;
-use Google::Ads::GoogleAds::V22::Resources::CampaignConversionGoal;
-use Google::Ads::GoogleAds::V22::Resources::AssetGroupListingGroupFilter;
-use Google::Ads::GoogleAds::V22::Common::MaximizeConversionValue;
-use Google::Ads::GoogleAds::V22::Common::LocationInfo;
-use Google::Ads::GoogleAds::V22::Common::LanguageInfo;
-use Google::Ads::GoogleAds::V22::Common::TextAsset;
-use Google::Ads::GoogleAds::V22::Common::ImageAsset;
-use Google::Ads::GoogleAds::V22::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V22::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V22::Enums::AdvertisingChannelTypeEnum
+use Google::Ads::GoogleAds::V23::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V23::Resources::Campaign;
+use Google::Ads::GoogleAds::V23::Resources::ShoppingSetting;
+use Google::Ads::GoogleAds::V23::Resources::CampaignCriterion;
+use Google::Ads::GoogleAds::V23::Resources::CampaignAsset;
+use Google::Ads::GoogleAds::V23::Resources::Asset;
+use Google::Ads::GoogleAds::V23::Resources::AssetAutomationSetting;
+use Google::Ads::GoogleAds::V23::Resources::AssetGroup;
+use Google::Ads::GoogleAds::V23::Resources::AssetGroupAsset;
+use Google::Ads::GoogleAds::V23::Resources::CampaignConversionGoal;
+use Google::Ads::GoogleAds::V23::Resources::AssetGroupListingGroupFilter;
+use Google::Ads::GoogleAds::V23::Common::MaximizeConversionValue;
+use Google::Ads::GoogleAds::V23::Common::LocationInfo;
+use Google::Ads::GoogleAds::V23::Common::LanguageInfo;
+use Google::Ads::GoogleAds::V23::Common::TextAsset;
+use Google::Ads::GoogleAds::V23::Common::ImageAsset;
+use Google::Ads::GoogleAds::V23::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V23::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V23::Enums::AdvertisingChannelTypeEnum
   qw(PERFORMANCE_MAX);
-use Google::Ads::GoogleAds::V22::Enums::AssetAutomationStatusEnum qw(OPTED_IN);
-use Google::Ads::GoogleAds::V22::Enums::AssetAutomationTypeEnum
+use Google::Ads::GoogleAds::V23::Enums::AssetAutomationStatusEnum qw(OPTED_IN);
+use Google::Ads::GoogleAds::V23::Enums::AssetAutomationTypeEnum
   qw(GENERATE_IMAGE_EXTRACTION FINAL_URL_EXPANSION_TEXT_ASSET_AUTOMATION TEXT_ASSET_AUTOMATION GENERATE_ENHANCED_YOUTUBE_VIDEOS GENERATE_IMAGE_ENHANCEMENT);
-use Google::Ads::GoogleAds::V22::Enums::AssetGroupStatusEnum;
-use Google::Ads::GoogleAds::V22::Enums::AssetFieldTypeEnum
+use Google::Ads::GoogleAds::V23::Enums::AssetGroupStatusEnum;
+use Google::Ads::GoogleAds::V23::Enums::AssetFieldTypeEnum
   qw(HEADLINE DESCRIPTION LONG_HEADLINE BUSINESS_NAME LOGO MARKETING_IMAGE SQUARE_MARKETING_IMAGE);
-use Google::Ads::GoogleAds::V22::Enums::ConversionActionCategoryEnum
+use Google::Ads::GoogleAds::V23::Enums::ConversionActionCategoryEnum
   qw(PURCHASE);
-use Google::Ads::GoogleAds::V22::Enums::ConversionOriginEnum qw(WEBSITE);
-use Google::Ads::GoogleAds::V22::Enums::ListingGroupFilterTypeEnum
+use Google::Ads::GoogleAds::V23::Enums::ConversionOriginEnum qw(WEBSITE);
+use Google::Ads::GoogleAds::V23::Enums::ListingGroupFilterTypeEnum
   qw(UNIT_INCLUDED);
-use Google::Ads::GoogleAds::V22::Enums::ListingGroupFilterListingSourceEnum
+use Google::Ads::GoogleAds::V23::Enums::ListingGroupFilterListingSourceEnum
   qw(SHOPPING);
-use Google::Ads::GoogleAds::V22::Enums::EuPoliticalAdvertisingStatusEnum
+use Google::Ads::GoogleAds::V23::Enums::EuPoliticalAdvertisingStatusEnum
   qw(DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING);
-use Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation;
+use Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation;
 use
-  Google::Ads::GoogleAds::V22::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V22::Services::CampaignService::CampaignOperation;
+  Google::Ads::GoogleAds::V23::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V23::Services::CampaignService::CampaignOperation;
 use
-  Google::Ads::GoogleAds::V22::Services::CampaignCriterionService::CampaignCriterionOperation;
-use Google::Ads::GoogleAds::V22::Services::AssetService::AssetOperation;
+  Google::Ads::GoogleAds::V23::Services::CampaignCriterionService::CampaignCriterionOperation;
+use Google::Ads::GoogleAds::V23::Services::AssetService::AssetOperation;
 use
-  Google::Ads::GoogleAds::V22::Services::AssetGroupService::AssetGroupOperation;
+  Google::Ads::GoogleAds::V23::Services::AssetGroupService::AssetGroupOperation;
 use
-  Google::Ads::GoogleAds::V22::Services::AssetGroupAssetService::AssetGroupAssetOperation;
+  Google::Ads::GoogleAds::V23::Services::AssetGroupAssetService::AssetGroupAssetOperation;
 use
-  Google::Ads::GoogleAds::V22::Services::CampaignConversionGoalService::CampaignConversionGoalOperation;
+  Google::Ads::GoogleAds::V23::Services::CampaignConversionGoalService::CampaignConversionGoalOperation;
 use
-  Google::Ads::GoogleAds::V22::Services::AssetGroupListingGroupFilterService::AssetGroupListingGroupFilterOperation;
+  Google::Ads::GoogleAds::V23::Services::AssetGroupListingGroupFilterService::AssetGroupListingGroupFilterOperation;
 use
-  Google::Ads::GoogleAds::V22::Services::CampaignAssetService::CampaignAssetOperation;
-use Google::Ads::GoogleAds::V22::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V23::Services::CampaignAssetService::CampaignAssetOperation;
+use Google::Ads::GoogleAds::V23::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -195,17 +195,17 @@ sub create_campaign_budget_operation {
 
   # Create a mutate operation that creates a campaign budget operation.
   return
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       campaignBudgetOperation =>
-        Google::Ads::GoogleAds::V22::Services::CampaignBudgetService::CampaignBudgetOperation
+        Google::Ads::GoogleAds::V23::Services::CampaignBudgetService::CampaignBudgetOperation
         ->new({
-          create => Google::Ads::GoogleAds::V22::Resources::CampaignBudget->new(
+          create => Google::Ads::GoogleAds::V23::Resources::CampaignBudget->new(
             {
               # Set a temporary ID in the budget's resource name so it can be
               # referenced by the campaign in later steps.
               resourceName =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               name => "Performance Max retail campaign budget #" . uniqid(),
@@ -236,7 +236,7 @@ sub create_performance_max_campaign_operation {
   my $asset_automation_settings = [];
   foreach my $asset_automation_type (@$asset_automation_types) {
     push @$asset_automation_settings,
-      Google::Ads::GoogleAds::V22::Resources::AssetAutomationSetting->new({
+      Google::Ads::GoogleAds::V23::Resources::AssetAutomationSetting->new({
         assetAutomationStatus => OPTED_IN,
         assetAutomationType   => $asset_automation_type
       });
@@ -244,27 +244,27 @@ sub create_performance_max_campaign_operation {
 
   # Create a mutate operation that creates a campaign operation.
   return
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       campaignOperation =>
-        Google::Ads::GoogleAds::V22::Services::CampaignService::CampaignOperation
+        Google::Ads::GoogleAds::V23::Services::CampaignService::CampaignOperation
         ->new({
-          create => Google::Ads::GoogleAds::V22::Resources::Campaign->new({
+          create => Google::Ads::GoogleAds::V23::Resources::Campaign->new({
               # Assign the resource name with a temporary ID.
               resourceName =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               name => "Performance Max retail campaign #'" . uniqid(),
               # Set the budget using the given budget resource name.
               campaignBudget =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               # Set the campaign status as PAUSED. The campaign is the only entity in
               # the mutate request that should have its status set.
               status =>
-                Google::Ads::GoogleAds::V22::Enums::CampaignStatusEnum::PAUSED,
+                Google::Ads::GoogleAds::V23::Enums::CampaignStatusEnum::PAUSED,
               # All Performance Max campaigns have an advertisingChannelType of
               # PERFORMANCE_MAX. The advertisingChannelSubType should not be set.
               advertisingChannelType => PERFORMANCE_MAX,
@@ -281,14 +281,14 @@ sub create_performance_max_campaign_operation {
               # A targetRoas of 3.5 corresponds to a 350% return on ad spend.
               # For first time users, it's recommended not to set a target ROAS.
               maximizeConversionValue =>
-                Google::Ads::GoogleAds::V22::Common::MaximizeConversionValue->
+                Google::Ads::GoogleAds::V23::Common::MaximizeConversionValue->
                 new({
                   targetRoas => 3.5
                 }
                 ),
               # Below is what you would use if you want to maximize conversions.
               # maximizeConversions =>
-              #   Google::Ads::GoogleAds::V22::Common::MaximizeConversions->
+              #   Google::Ads::GoogleAds::V23::Common::MaximizeConversions->
               #   new({
               #     targetCpaMicros => 1000000
               #   }
@@ -298,7 +298,7 @@ sub create_performance_max_campaign_operation {
 
               # Set the shopping settings.
               shoppingSetting =>
-                Google::Ads::GoogleAds::V22::Resources::ShoppingSetting->new({
+                Google::Ads::GoogleAds::V23::Resources::ShoppingSetting->new({
                   merchantId => $merchant_center_account_id,
                   # Optional: To use products only from a specific feed, set feedLabel
                   # to the feed label used in Merchant Center.
@@ -322,9 +322,12 @@ sub create_performance_max_campaign_operation {
               assetAutomationSettings => $asset_automation_settings,
 
               # Optional fields.
-              startDate => strftime("%Y%m%d", localtime(time + 60 * 60 * 24)),
-              endDate   =>
-                strftime("%Y%m%d", localtime(time + 60 * 60 * 24 * 365)),
+              startDateTime =>
+                strftime("%Y%m%d 00:00:00", localtime(time + 60 * 60 * 24)),
+              endDateTime => strftime(
+                "%Y%m%d 23:59:59",
+                localtime(time + 60 * 60 * 24 * 365)
+              ),
             })})});
 }
 # [END add_performance_max_retail_campaign_3]
@@ -342,23 +345,23 @@ sub create_campaign_criterion_operations {
   # and they can also be retrieved using the GeoTargetConstantService as shown
   # here: https://developers.google.com/google-ads/api/docs/targeting/location-targeting.
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V22::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V23::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V22::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V23::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               # Adds one positive location target for New York City (ID=1023191),
               # specifically adding the positive criteria before the negative one.
               location =>
-                Google::Ads::GoogleAds::V22::Common::LocationInfo->new({
+                Google::Ads::GoogleAds::V23::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V22::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V23::Utils::ResourceNames::geo_target_constant(
                     1023191)}
                 ),
               negative => "false"
@@ -366,21 +369,21 @@ sub create_campaign_criterion_operations {
 
   # Next add the negative target for Brooklyn (ID=1022762).
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V22::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V23::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V22::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V23::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               location =>
-                Google::Ads::GoogleAds::V22::Common::LocationInfo->new({
+                Google::Ads::GoogleAds::V23::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V22::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V23::Utils::ResourceNames::geo_target_constant(
                     1022762)}
                 ),
               negative => "true"
@@ -388,24 +391,24 @@ sub create_campaign_criterion_operations {
 
   # Set the LANGUAGE campaign criterion.
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V22::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V23::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V22::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V23::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               # Set the language.
               # For a list of all language codes, see:
               # https://developers.google.com/google-ads/api/reference/data/codes-formats#expandable-7.
               language =>
-                Google::Ads::GoogleAds::V22::Common::LanguageInfo->new({
+                Google::Ads::GoogleAds::V23::Common::LanguageInfo->new({
                   languageConstant =>
-                    Google::Ads::GoogleAds::V22::Utils::ResourceNames::language_constant(
+                    Google::Ads::GoogleAds::V23::Utils::ResourceNames::language_constant(
                     1000)    # English
                 })})})});
 
@@ -427,14 +430,14 @@ sub create_multiple_text_assets {
   foreach my $text (@$texts) {
     # Create a mutate operation for a text asset.
     push @$operations,
-      Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation
       ->new({
         assetOperation =>
-          Google::Ads::GoogleAds::V22::Services::AssetService::AssetOperation->
+          Google::Ads::GoogleAds::V23::Services::AssetService::AssetOperation->
           new({
-            create => Google::Ads::GoogleAds::V22::Resources::Asset->new({
+            create => Google::Ads::GoogleAds::V23::Resources::Asset->new({
                 textAsset =>
-                  Google::Ads::GoogleAds::V22::Common::TextAsset->new({
+                  Google::Ads::GoogleAds::V23::Common::TextAsset->new({
                     text => $text
                   })})})});
   }
@@ -467,25 +470,25 @@ sub create_asset_group_operation {
 
   # Create a mutate operation that creates an asset group operation.
   return
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupOperation =>
-        Google::Ads::GoogleAds::V22::Services::AssetGroupService::AssetGroupOperation
+        Google::Ads::GoogleAds::V23::Services::AssetGroupService::AssetGroupOperation
         ->new({
-          create => Google::Ads::GoogleAds::V22::Resources::AssetGroup->new({
+          create => Google::Ads::GoogleAds::V23::Resources::AssetGroup->new({
               resourceName =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               name     => "Performance Max retail asset group #" . uniqid(),
               campaign =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               finalUrls       => [$final_url],
               finalMobileUrls => [$final_url],
               status          =>
-                Google::Ads::GoogleAds::V22::Enums::AssetGroupStatusEnum::PAUSED
+                Google::Ads::GoogleAds::V23::Enums::AssetGroupStatusEnum::PAUSED
             })})});
 }
 # [END add_performance_max_retail_campaign_10]
@@ -500,9 +503,9 @@ sub create_listing_group_filter_operation {
   # Creates a new ad group criterion containing the "default" listing group
   # (All products).
   my $listing_group_filter =
-    Google::Ads::GoogleAds::V22::Resources::AssetGroupListingGroupFilter->new({
+    Google::Ads::GoogleAds::V23::Resources::AssetGroupListingGroupFilter->new({
       assetGroup =>
-        Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset_group(
+        Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset_group(
         $customer_id, ASSET_GROUP_TEMPORARY_ID
         ),
 
@@ -521,10 +524,10 @@ sub create_listing_group_filter_operation {
     });
 
   return
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupListingGroupFilterOperation =>
-        Google::Ads::GoogleAds::V22::Services::AssetGroupListingGroupFilterService::AssetGroupListingGroupFilterOperation
+        Google::Ads::GoogleAds::V23::Services::AssetGroupListingGroupFilterService::AssetGroupListingGroupFilterOperation
         ->new({
           create => $listing_group_filter
         })});
@@ -561,16 +564,16 @@ sub create_asset_and_asset_group_asset_operations {
   # Link the headline assets.
   foreach my $resource_name (@$headline_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation
       ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V22::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V23::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V22::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V23::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => HEADLINE
@@ -580,16 +583,16 @@ sub create_asset_and_asset_group_asset_operations {
   # Link the description assets.
   foreach my $resource_name (@$description_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation
       ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V22::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V23::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V22::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V23::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => DESCRIPTION
@@ -643,34 +646,34 @@ sub create_and_link_text_asset {
   my $operations = [];
   # Create a new mutate operation for a text asset.
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V22::Services::AssetService::AssetOperation->
+        Google::Ads::GoogleAds::V23::Services::AssetService::AssetOperation->
         new({
-          create => Google::Ads::GoogleAds::V22::Resources::Asset->new({
+          create => Google::Ads::GoogleAds::V23::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
-              textAsset => Google::Ads::GoogleAds::V22::Common::TextAsset->new({
+              textAsset => Google::Ads::GoogleAds::V23::Common::TextAsset->new({
                   text => $text
                 })})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V22::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V23::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V22::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V23::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -689,14 +692,14 @@ sub create_and_link_image_asset {
   my $operations = [];
   # Create a new mutate operation for an image asset.
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V22::Services::AssetService::AssetOperation->
+        Google::Ads::GoogleAds::V23::Services::AssetService::AssetOperation->
         new({
-          create => Google::Ads::GoogleAds::V22::Resources::Asset->new({
+          create => Google::Ads::GoogleAds::V23::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
               # Provide a unique friendly name to identify your asset.
@@ -704,23 +707,23 @@ sub create_and_link_image_asset {
               # name, the new name will be dropped silently.
               name       => $asset_name,
               imageAsset =>
-                Google::Ads::GoogleAds::V22::Common::ImageAsset->new({
+                Google::Ads::GoogleAds::V23::Common::ImageAsset->new({
                   data => get_base64_data_from_url($url)})})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V22::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V23::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V22::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V23::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -742,31 +745,31 @@ sub create_and_link_brand_assets {
   # Create the text asset.
   my $text_asset_temp_id = $next_temp_id--;
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V22::Services::AssetService::AssetOperation->
+        Google::Ads::GoogleAds::V23::Services::AssetService::AssetOperation->
         new({
-          create => Google::Ads::GoogleAds::V22::Resources::Asset->new({
+          create => Google::Ads::GoogleAds::V23::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                 $customer_id, $text_asset_temp_id
                 ),
-              textAsset => Google::Ads::GoogleAds::V22::Common::TextAsset->new({
+              textAsset => Google::Ads::GoogleAds::V23::Common::TextAsset->new({
                   text => $business_name
                 })})})});
 
   # Create the image asset.
   my $image_asset_temp_id = $next_temp_id--;
   push @$operations,
-    Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V22::Services::AssetService::AssetOperation->
+        Google::Ads::GoogleAds::V23::Services::AssetService::AssetOperation->
         new({
-          create => Google::Ads::GoogleAds::V22::Resources::Asset->new({
+          create => Google::Ads::GoogleAds::V23::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                 $customer_id, $image_asset_temp_id
                 ),
               # Provide a unique friendly name to identify your asset.
@@ -774,81 +777,81 @@ sub create_and_link_brand_assets {
               # name, the new name will be dropped silently.
               name       => $logo_name,
               imageAsset =>
-                Google::Ads::GoogleAds::V22::Common::ImageAsset->new({
+                Google::Ads::GoogleAds::V23::Common::ImageAsset->new({
                   data => get_base64_data_from_url($logo_url)})})})});
 
   if ($brand_guidelines_enabled) {
     # Create CampaignAsset resources to link the Asset resources to the Campaign.
     push @$operations,
-      Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation
       ->new({
         campaignAssetOperation =>
-          Google::Ads::GoogleAds::V22::Services::CampaignAssetService::CampaignAssetOperation
+          Google::Ads::GoogleAds::V23::Services::CampaignAssetService::CampaignAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V22::Resources::CampaignAsset->new({
+              Google::Ads::GoogleAds::V23::Resources::CampaignAsset->new({
                 fieldType => BUSINESS_NAME,
                 campaign  =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign(
                   $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                   ),
                 asset =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                   $customer_id, $text_asset_temp_id
                   )})})});
 
     push @$operations,
-      Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation
       ->new({
         campaignAssetOperation =>
-          Google::Ads::GoogleAds::V22::Services::CampaignAssetService::CampaignAssetOperation
+          Google::Ads::GoogleAds::V23::Services::CampaignAssetService::CampaignAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V22::Resources::CampaignAsset->new({
+              Google::Ads::GoogleAds::V23::Resources::CampaignAsset->new({
                 fieldType => LOGO,
                 campaign  =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign(
                   $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                   ),
                 asset =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                   $customer_id, $image_asset_temp_id
                   )})})});
   } else {
     # Create AssetGroupAsset resources to link the Asset resources to the AssetGroup.
     push @$operations,
-      Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation
       ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V22::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V23::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V22::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V23::Resources::AssetGroupAsset->new({
                 asset =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                   $customer_id, $text_asset_temp_id
                   ),
                 assetGroup =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => BUSINESS_NAME
               })})});
 
     push @$operations,
-      Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation
       ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V22::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V23::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V22::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V23::Resources::AssetGroupAsset->new({
                 asset =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset(
                   $customer_id, $image_asset_temp_id
                   ),
                 assetGroup =>
-                  Google::Ads::GoogleAds::V22::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V23::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => LOGO
@@ -917,9 +920,9 @@ sub create_conversion_goal_operations {
   # is biddable in this campaign.
   foreach my $customer_conversion_goal (@$customer_conversion_goals) {
     my $campaign_conversion_goal =
-      Google::Ads::GoogleAds::V22::Resources::CampaignConversionGoal->new({
+      Google::Ads::GoogleAds::V23::Resources::CampaignConversionGoal->new({
         resourceName =>
-          Google::Ads::GoogleAds::V22::Utils::ResourceNames::campaign_conversion_goal(
+          Google::Ads::GoogleAds::V23::Utils::ResourceNames::campaign_conversion_goal(
           $customer_id,
           PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID,
           $customer_conversion_goal->{category},
@@ -941,10 +944,10 @@ sub create_conversion_goal_operations {
     }
 
     push @$operations,
-      Google::Ads::GoogleAds::V22::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V23::Services::GoogleAdsService::MutateOperation
       ->new({
         campaignConversionGoalOperation =>
-          Google::Ads::GoogleAds::V22::Services::CampaignConversionGoalService::CampaignConversionGoalOperation
+          Google::Ads::GoogleAds::V23::Services::CampaignConversionGoalService::CampaignConversionGoalOperation
           ->new({
             update => $campaign_conversion_goal,
             # Set the update mask on the operation. Here the update mask will be
