@@ -64,38 +64,40 @@ sub new {
     manualCpv                      => $args->{manualCpv},
     maximizeConversionValue        => $args->{maximizeConversionValue},
     maximizeConversions            => $args->{maximizeConversions},
-    name                           => $args->{name},
-    networkSettings                => $args->{networkSettings},
-    optimizationGoalSetting        => $args->{optimizationGoalSetting},
-    optimizationScore              => $args->{optimizationScore},
-    paymentMode                    => $args->{paymentMode},
-    percentCpc                     => $args->{percentCpc},
-    performanceMaxUpgrade          => $args->{performanceMaxUpgrade},
-    pmaxCampaignSettings           => $args->{pmaxCampaignSettings},
-    primaryStatus                  => $args->{primaryStatus},
-    primaryStatusReasons           => $args->{primaryStatusReasons},
-    realTimeBiddingSetting         => $args->{realTimeBiddingSetting},
-    resourceName                   => $args->{resourceName},
-    selectiveOptimization          => $args->{selectiveOptimization},
-    servingStatus                  => $args->{servingStatus},
-    shoppingSetting                => $args->{shoppingSetting},
-    startDate                      => $args->{startDate},
-    status                         => $args->{status},
-    targetCpa                      => $args->{targetCpa},
-    targetCpm                      => $args->{targetCpm},
-    targetCpv                      => $args->{targetCpv},
-    targetImpressionShare          => $args->{targetImpressionShare},
-    targetRoas                     => $args->{targetRoas},
-    targetSpend                    => $args->{targetSpend},
-    targetingSetting               => $args->{targetingSetting},
-    trackingSetting                => $args->{trackingSetting},
-    trackingUrlTemplate            => $args->{trackingUrlTemplate},
-    travelCampaignSettings         => $args->{travelCampaignSettings},
-    urlCustomParameters            => $args->{urlCustomParameters},
-    urlExpansionOptOut             => $args->{urlExpansionOptOut},
-    vanityPharma                   => $args->{vanityPharma},
-    videoBrandSafetySuitability    => $args->{videoBrandSafetySuitability},
-    videoCampaignSettings          => $args->{videoCampaignSettings}};
+    missingEuPoliticalAdvertisingDeclaration =>
+      $args->{missingEuPoliticalAdvertisingDeclaration},
+    name                        => $args->{name},
+    networkSettings             => $args->{networkSettings},
+    optimizationGoalSetting     => $args->{optimizationGoalSetting},
+    optimizationScore           => $args->{optimizationScore},
+    paymentMode                 => $args->{paymentMode},
+    percentCpc                  => $args->{percentCpc},
+    performanceMaxUpgrade       => $args->{performanceMaxUpgrade},
+    pmaxCampaignSettings        => $args->{pmaxCampaignSettings},
+    primaryStatus               => $args->{primaryStatus},
+    primaryStatusReasons        => $args->{primaryStatusReasons},
+    realTimeBiddingSetting      => $args->{realTimeBiddingSetting},
+    resourceName                => $args->{resourceName},
+    selectiveOptimization       => $args->{selectiveOptimization},
+    servingStatus               => $args->{servingStatus},
+    shoppingSetting             => $args->{shoppingSetting},
+    startDate                   => $args->{startDate},
+    status                      => $args->{status},
+    targetCpa                   => $args->{targetCpa},
+    targetCpm                   => $args->{targetCpm},
+    targetCpv                   => $args->{targetCpv},
+    targetImpressionShare       => $args->{targetImpressionShare},
+    targetRoas                  => $args->{targetRoas},
+    targetSpend                 => $args->{targetSpend},
+    targetingSetting            => $args->{targetingSetting},
+    trackingSetting             => $args->{trackingSetting},
+    trackingUrlTemplate         => $args->{trackingUrlTemplate},
+    travelCampaignSettings      => $args->{travelCampaignSettings},
+    urlCustomParameters         => $args->{urlCustomParameters},
+    urlExpansionOptOut          => $args->{urlExpansionOptOut},
+    vanityPharma                => $args->{vanityPharma},
+    videoBrandSafetySuitability => $args->{videoBrandSafetySuitability},
+    videoCampaignSettings       => $args->{videoCampaignSettings}};
 
   # Delete the unassigned fields in this object for a more concise JSON payload
   remove_unassigned_fields($self, $args);
