@@ -24,7 +24,8 @@ use Const::Exporter enums => [
   AI_MAX_KEYWORDLESS          => "AI_MAX_KEYWORDLESS",
   AI_MAX_BROAD_MATCH          => "AI_MAX_BROAD_MATCH",
   DYNAMIC_SEARCH_ADS          => "DYNAMIC_SEARCH_ADS",
-  PERFORMANCE_MAX             => "PERFORMANCE_MAX"
+  PERFORMANCE_MAX             => "PERFORMANCE_MAX",
+  VERTICAL_ADS_DATA_FEED      => "VERTICAL_ADS_DATA_FEED"
 ];
 
 1;
